import os
import tkinter as tk
from tkinter import messagebox
from tkinter import PhotoImage

# Constantes de licencia
CODIGO_LICENCIA = ["QSSD", "2024", "08", "001"]
NOMBRE_CLIENTE = "Isabel Macías"
RUTA_ARCHIVO_CODIGO = "/opt/activar/codigo.txt"
RUTA_LOGOTIPO = "/opt/activar/quirinux_logo.png"

def verificar_licencia():
    licencia_ingresada = [campo_qssd.get().upper(), campo_2024.get(), campo_08.get(), campo_001.get()]
    if licencia_ingresada == CODIGO_LICENCIA:
        with open(RUTA_ARCHIVO_CODIGO, "w") as archivo:
            archivo.write("-".join(licencia_ingresada))
        messagebox.showinfo("Activación exitosa", f"Copia activada a nombre de:\n{NOMBRE_CLIENTE}")
        ventana.destroy()  # Cierra la ventana después de la activación
    else:
        messagebox.showerror("Error de activación", "Código de licencia incorrecto. Intenta otra vez.")

def comprobar_activar():
    return os.path.exists(RUTA_ARCHIVO_CODIGO)

def limitar_caracteres(event, max_length):
    """Limitar el número de caracteres en el campo."""
    if len(event.widget.get()) > max_length:
        event.widget.delete(max_length, tk.END)

def mover_siguiente(event, siguiente_campo, max_length):
    """Mover el foco al siguiente campo si se alcanza la longitud máxima."""
    limitar_caracteres(event, max_length)
    if len(event.widget.get()) >= max_length:
        siguiente_campo.focus_set()

def forzar_ventana_al_frente():
    """Forzar que la ventana se mantenga en la parte superior repetidamente."""
    ventana.lift()
    ventana.attributes("-topmost", True)
    ventana.after(500, forzar_ventana_al_frente)  # Vuelve a llamar a esta función cada 500 ms

# Verificar si el sistema ya está activado
if not comprobar_activar():
    # Crear la ventana principal
    ventana = tk.Tk()
    ventana.title("Activación de Licencia")
    
    # Configuración de la ventana en pantalla completa
    ventana.attributes("-fullscreen", True)
    ventana.attributes("-topmost", True)  # Mantener siempre al frente
    ventana.resizable(False, False)

    # Forzar a que la ventana cubra completamente la pantalla
    ventana.geometry(f"{ventana.winfo_screenwidth()}x{ventana.winfo_screenheight()}+0+0")

    # Agregar logotipo de Quirinux
    logotipo = PhotoImage(file=RUTA_LOGOTIPO)
    etiqueta_logo = tk.Label(ventana, image=logotipo)
    etiqueta_logo.pack(pady=20)

    # Mensaje de bienvenida
    mensaje_bienvenida = (
        "Te damos la bienvenida a tu sistema Quirinux Preinstalado.\n"
        "Vamos a activar tu licencia, luego ya no volverás a ver este mensaje.\n"
        "Encuentra el número de serie en la etiqueta de tu equipo o de tu disco SSD."
    )
    etiqueta_bienvenida = tk.Label(ventana, text=mensaje_bienvenida, font=("Ubuntu", 16), justify="center", wraplength=800)
    etiqueta_bienvenida.pack(pady=20)

    # Ingrese el código de licencia
    etiqueta = tk.Label(ventana, text="Ingresa tu S/N:", font=("Ubuntu", 18))
    etiqueta.pack(pady=10)

    # Crear los campos de entrada para cada parte del código
    marco_entrada = tk.Frame(ventana)
    marco_entrada.pack(pady=20)

    campo_qssd = tk.Entry(marco_entrada, font=("Ubuntu", 18), width=6, justify='center')
    campo_qssd.grid(row=0, column=0, padx=10)
    campo_qssd.bind('<KeyRelease>', lambda event: mover_siguiente(event, campo_2024, 4))

    campo_2024 = tk.Entry(marco_entrada, font=("Ubuntu", 18), width=6, justify='center')
    campo_2024.grid(row=0, column=1, padx=10)
    campo_2024.bind('<KeyRelease>', lambda event: mover_siguiente(event, campo_08, 4))

    campo_08 = tk.Entry(marco_entrada, font=("Ubuntu", 18), width=3, justify='center')
    campo_08.grid(row=0, column=2, padx=10)
    campo_08.bind('<KeyRelease>', lambda event: mover_siguiente(event, campo_001, 2))

    campo_001 = tk.Entry(marco_entrada, font=("Ubuntu", 18), width=4, justify='center')
    campo_001.grid(row=0, column=3, padx=10)
    campo_001.bind('<KeyRelease>', lambda event: limitar_caracteres(event, 3))
    
    boton_activar = tk.Button(ventana, text="Activar", font=("Ubuntu", 16), command=verificar_licencia)
    boton_activar.pack(pady=20)

    # Forzar la ventana a estar siempre al frente usando un bucle
    ventana.after(500, forzar_ventana_al_frente)

    # Prevenir el cierre de la ventana
    ventana.protocol("WM_DELETE_WINDOW", lambda: None)

    ventana.mainloop()
